@@ -15,6 +15,8 @@
 
 #include <QLabel>
 #include <QPushButton>
+#include <QCloseEvent>
+#include <QScrollBar>
 
 #define MAINWINDOW_WIDTH    696
 #define MAINWINDOW_HEIGHT   529
@@ -81,9 +83,16 @@ void ConfigWidget::initUI()
 
 void ConfigWidget::closeEvent(QCloseEvent *event)
 {
-    m_indexWidget->onCloseEvent();
+    if (!m_indexWidget->onCloseEvent())
+        event->ignore();
 }
 
 void ConfigWidget::initData()
 {
 }
+
+void ConfigWidget::scrollToAiConfig()
+{
+    QPoint targetPos = m_indexWidget->mapTo(m_scrollArea->viewport(), QPoint(0, 0));
+    m_scrollArea->verticalScrollBar()->setValue(targetPos.y());
+}
