@@ -32,23 +32,13 @@ extern "C" {
 #include <QIcon>
 #include <QApplication>
 #include <DUtil>
+#include <DSysInfo>
 
 DCORE_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 DGUI_USE_NAMESPACE
 using namespace GrandSearch;
 
-#ifdef COMPILE_ON_V23
-static const QString AppManagerService = "org.desktopspec.ApplicationManager1";
-static const QString AppManagerPathPrefix = "/org/desktopspec/ApplicationManager1";
-static const QString AppInterface = "org.desktopspec.ApplicationManager1.Application";
-
-#else
-static const QString SessionManagerService = "com.deepin.SessionManager";
-static const QString StartManagerPath = "/com/deepin/StartManager";
-static const QString StartManagerInterface = "com.deepin.StartManager";
-#endif
-
 static const int WeightDiffLimit = 21;
 
 static const int CreateDateType = 1;
@@ -71,11 +61,17 @@ QMimeDatabase Utils::m_mimeDb;
 
 bool Utils::sort(MatchedItems &list, Qt::SortOrder order/* = Qt::AscendingOrder*/)
 {
-    QTime time;
+    QElapsedTimer time;
     time.start();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     qStableSort(list.begin(), list.end(), [order](const MatchedItem &node1, const MatchedItem &node2) {
         return compareByString(node1.name, node2.name, order);
     });
+#else
+    std::stable_sort(list.begin(), list.end(), [order](const MatchedItem &node1, const MatchedItem &node2) {
+        return compareByString(node1.name, node2.name, order);
+    });
+#endif
 
     qDebug() << QString("sort matchItems done. cost [%1]ms").arg(time.elapsed());
     return true;
@@ -154,8 +150,8 @@ bool Utils::startWithSymbol(const QString &text)
 
     bool bRet = false;
     // 先匹配中文标点符号
-    QRegExp regExp("^[\u3002\uff1b\uff0c\uff1a\u201c\u201d\uff08\uff09\u3001\uff1f\u300a\u300b].*$");
-    bRet = regExp.exactMatch(text.at(0));
+    QRegularExpression regExp("^[\u3002\uff1b\uff0c\uff1a\u201c\u201d\uff08\uff09\u3001\uff1f\u300a\u300b].*$");
+    bRet = regExp.match(text.at(0)).hasMatch();
 
     // 若不是中文标点符号，再判断是否为其他符号
     if (!bRet)
@@ -170,8 +166,8 @@ bool Utils::startWithHanzi(const QString &text)
         return false;
 
     // 匹配中文
-    QRegExp regExp("^[\u4e00-\u9fa5].*$");
-    bool bRet = regExp.exactMatch(text.at(0));
+    QRegularExpression regExp("^[\u4e00-\u9fa5].*$");
+    bool bRet = regExp.match(text.at(0)).hasMatch();
 
     return bRet;
 }
@@ -182,8 +178,8 @@ bool Utils::startWithLatin(const QString &text)
         return false;
 
     // 匹配英文
-    QRegExp regExp("^[a-zA-Z].*$");
-    bool bRet = regExp.exactMatch(text.at(0));
+    QRegularExpression regExp("^[a-zA-Z].*$");
+    bool bRet = regExp.match(text.at(0)).hasMatch();
 
     return bRet;
 }
@@ -210,15 +206,15 @@ bool Utils::startWidthNum(const QString &text)
         return false;
 
     // 匹配数字
-    QRegExp regExp("^[0-9].*$");
-    bool bRet = regExp.exactMatch(text.at(0));
+    QRegularExpression regExp("^[0-9].*$");
+    bool bRet = regExp.match(text.at(0)).hasMatch();
 
     return bRet;
 }
 
 bool Utils::sortByWeight(MatchedItemMap &map, Qt::SortOrder order)
 {
-    QTime time;
+    QElapsedTimer time;
     time.start();
 
     for (const QString &searchGroupName : map.keys()) {
@@ -321,9 +317,7 @@ bool Utils::setWeightMethod(MatchedItem &item)
         return true;
 
     const QString &search = item.searcher;
-    if (search == GRANDSEARCH_CLASS_FILE_DEEPIN ||
-            search == GRANDSEARCH_CLASS_FILE_FSEARCH) {
-
+    if (search == GRANDSEARCH_CLASS_FILE_DEEPIN) {
         ext.insert(GRANDSEARCH_PROPERTY_WEIGHT_METHOD,
                    GRANDSEARCH_PROPERTY_WEIGHT_METHOD_LOCALFILE);
     } else if (search == GRANDSEARCH_CLASS_APP_DESKTOP) {
@@ -362,7 +356,11 @@ double Utils::calcFileWeight(const QString &path, const QString &name, const QSt
     QFileInfo fileInfo(path);
 
     const QDateTime &currentDateTime = QDateTime::currentDateTime();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    const QDateTime &createDateTime = fileInfo.birthTime();
+#else
     const QDateTime &createDateTime = fileInfo.created();
+#endif
     const QDateTime &lastModifyTime = fileInfo.lastModified();
     const QDateTime &lastReadTime = fileInfo.lastRead();
 
@@ -485,12 +483,11 @@ void Utils::packageBestMatch(MatchedItemMap &map, int maxQuantity)
     if (map.isEmpty() || maxQuantity <= 0)
         return;
 
-    QTime time;
+    QElapsedTimer time;
     time.start();
 
     static const QMap<QString, bool> supprotedSeracher = {
         {GRANDSEARCH_CLASS_FILE_DEEPIN, true},
-        {GRANDSEARCH_CLASS_FILE_FSEARCH, true},
         {GRANDSEARCH_CLASS_APP_DESKTOP, true},
         {GRANDSEARCH_CLASS_SETTING_CONTROLCENTER, true},
     };
@@ -560,7 +557,16 @@ void Utils::packageBestMatch(MatchedItemMap &map, int maxQuantity)
 
     for (auto list : tempBestList) {
         // 在原分组中移除最佳匹配项
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        auto& items = map[list.second];
+        auto it = std::find(items.begin(), items.end(), list.first);
+        if (it != items.end()) {
+            items.erase(it);
+        }
+#else
         map[list.second].removeOne(list.first);
+#endif
+
         bestList.append(list.first);
 
         // 原分组为空，移除分组
@@ -765,7 +771,7 @@ bool Utils::openMatchedItem(const MatchedItem &item)
 
 bool Utils::openMatchedItemWithCtrl(const MatchedItem &item)
 {
-    if (GRANDSEARCH_CLASS_FILE_DEEPIN == item.searcher || GRANDSEARCH_CLASS_FILE_FSEARCH == item.searcher) {
+    if (GRANDSEARCH_CLASS_FILE_DEEPIN == item.searcher) {
         QFileInfo fileInfo(item.item);
         if (!fileInfo.isDir())
             return openInFileManager(item);
@@ -783,7 +789,8 @@ bool Utils::openExtendSearchMatchedItem(const MatchedItem &item)
 {
     // 搜索结果来自扩展插件，使用Dbus通知主控调用扩展插件打开接口打开搜索结果
     DaemonGrandSearchInterface daemonDbus;
-    daemonDbus.OpenWithPlugin(item.searcher, item.item);
+    auto reply = daemonDbus.OpenWithPlugin(item.searcher, item.item);
+    reply.waitForFinished();
 
     return true;
 }
@@ -829,7 +836,6 @@ bool Utils::launchApp(const QString& desktopFile, const QStringList &filePaths)
 
 bool Utils::launchAppByDBus(const QString &desktopFile, const QStringList &filePaths)
 {
-#ifdef COMPILE_ON_V23
     const auto &file = QFileInfo{desktopFile};
     constexpr auto kDesktopSuffix { u8"desktop" };
 
@@ -838,38 +844,48 @@ bool Utils::launchAppByDBus(const QString &desktopFile, const QStringList &fileP
         return false;
     }
 
-    const auto &DBusAppId = DUtil::escapeToObjectPath(file.completeBaseName());
-    const auto &currentAppPath = QString { AppManagerPathPrefix } + "/" + DBusAppId;
-    qDebug() << "app object path:" << currentAppPath;
-    QDBusInterface appManager(AppManagerService,
-                              currentAppPath,
-                              AppInterface,
-                              QDBusConnection::sessionBus());
+    auto ver = DSysInfo::majorVersion().toInt();
+    if (ver > 20) {
 
-    auto reply = appManager.callWithArgumentList(QDBus::Block, QStringLiteral("Launch"), { QVariant::fromValue(QString {}), QVariant::fromValue(filePaths), QVariant::fromValue(QVariantMap {}) });
+        const QString AppManagerService = "org.desktopspec.ApplicationManager1";
+        const QString AppManagerPathPrefix = "/org/desktopspec/ApplicationManager1";
+        const QString AppInterface = "org.desktopspec.ApplicationManager1.Application";
 
-    return reply.type() == QDBusMessage::ReplyMessage;
+        const auto &DBusAppId = DUtil::escapeToObjectPath(file.completeBaseName());
+        const auto &currentAppPath = QString { AppManagerPathPrefix } + "/" + DBusAppId;
+        qDebug() << "app object path:" << currentAppPath;
 
-#else
-    QDBusInterface interface(SessionManagerService,
-                             StartManagerPath,
-                             StartManagerInterface,
-                             QDBusConnection::sessionBus(),
-                             qApp);
+        QDBusInterface appManager(AppManagerService,
+                                currentAppPath,
+                                AppInterface,
+                                QDBusConnection::sessionBus());
 
-    QList<QVariant> args;
-    args << desktopFile
-         << QDateTime::currentDateTime().toTime_t()
-         << filePaths;
+        auto reply = appManager.callWithArgumentList(QDBus::Block, QStringLiteral("Launch"), { QVariant::fromValue(QString {}), QVariant::fromValue(filePaths), QVariant::fromValue(QVariantMap {}) });
 
-    QDBusPendingCall call = interface.asyncCallWithArgumentList("LaunchApp", args);
+        return reply.type() == QDBusMessage::ReplyMessage;
+    } else {
+        // V20 Use the SessionManager to launch app
+        const QString SessionManagerService = "com.deepin.SessionManager";
+        const QString StartManagerPath = "/com/deepin/StartManager";
+        const QString StartManagerInterface = "com.deepin.StartManager";
+        QDBusInterface interface(SessionManagerService,
+                                StartManagerPath,
+                                StartManagerInterface,
+                                QDBusConnection::sessionBus());
 
-    QDBusReply<void> reply = call.reply();
-    if (!reply.isValid()) {
-            qCritical() << "Launch app by DBus failed:" << reply.error();
-            return false;
+        QList<QVariant> args;
+        args << desktopFile
+            << QDateTime::currentDateTime().toSecsSinceEpoch()
+            << filePaths;
+
+        QDBusPendingCall call = interface.asyncCallWithArgumentList("LaunchApp", args);
+
+        QDBusReply<void> reply = call.reply();
+        if (!reply.isValid()) {
+                qCritical() << "Launch app by DBus failed:" << reply.error();
+                return false;
+        }
     }
-#endif
 
     return true;
 }
@@ -936,7 +952,7 @@ QIcon Utils::defaultIcon(const MatchedItem &item)
 {
     if (item.searcher == GRANDSEARCH_CLASS_APP_DESKTOP)
         return QIcon::fromTheme("application-x-desktop");
-    else if (item.searcher == GRANDSEARCH_CLASS_FILE_DEEPIN || item.searcher == GRANDSEARCH_CLASS_FILE_FSEARCH) {
+    else if (item.searcher == GRANDSEARCH_CLASS_FILE_DEEPIN) {
         return QIcon::fromTheme(m_mimeDb.mimeTypeForFile(item.item).genericIconName());
     } else if (item.searcher == GRANDSEARCH_CLASS_WEB_STATICTEXT) {
         // 使用默认浏览器的图标
